==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_entities/extmenus_001/ExtMenus.java <==

package net.datastream.schemas.mp_entities.extmenus_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMENUID_Type;
import net.datastream.schemas.mp_fields.FUNCTIONID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extmenuid",
    "usergroupid",
    "functionid",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "updatecount"
})
@XmlRootElement(name = "ExtMenus")
public class ExtMenus {

    @XmlElement(name = "EXTMENUID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EXTMENUID_Type extmenuid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "FUNCTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "EXTMENUPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU", namespace = "http://schemas.datastream.net/MP_fields")
    protected String hidemenu;
    @XmlElement(name = "MOBILE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobile;
    @XmlElement(name = "MOBILEICON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobileicon;
    @XmlElement(name = "UPDATECOUNT")
    protected Long updatecount;

    /**
     * Obtient la valeur de la propriété extmenuid.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public EXTMENUID_Type getEXTMENUID() {
        return extmenuid;
    }

    /**
     * Définit la valeur de la propriété extmenuid.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public void setEXTMENUID(EXTMENUID_Type value) {
        this.extmenuid = value;
    }

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété functionid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Définit la valeur de la propriété functionid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Obtient la valeur de la propriété extmenuparent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Définit la valeur de la propriété extmenuparent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Obtient la valeur de la propriété extmenutype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Définit la valeur de la propriété extmenutype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Obtient la valeur de la propriété hidemenu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Définit la valeur de la propriété hidemenu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Obtient la valeur de la propriété mobile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Définit la valeur de la propriété mobile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Obtient la valeur de la propriété mobileicon.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Définit la valeur de la propriété mobileicon.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Obtient la valeur de la propriété updatecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Définit la valeur de la propriété updatecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUPDATECOUNT(Long value) {
        this.updatecount = value;
    }

}

==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_entities/extmenus_001/ExtMenus.java <==

package net.datastream.schemas.mp_entities.extmenus_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EXTMAINMENUTYPE_Type;
import net.datastream.schemas.mp_fields.EXTMENUID_Type;
import net.datastream.schemas.mp_fields.FUNCTIONID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMAINMENUTYPE" minOccurs="0"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extmenuid",
    "usergroupid",
    "functionid",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "extmainmenutype",
    "updatecount"
})
@XmlRootElement(name = "ExtMenus")
public class ExtMenus {

    @XmlElement(name = "EXTMENUID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EXTMENUID_Type extmenuid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "FUNCTIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "EXTMENUPARENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU", namespace = "http://schemas.datastream.net/MP_fields")
    protected String hidemenu;
    @XmlElement(name = "MOBILE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobile;
    @XmlElement(name = "MOBILEICON", namespace = "http://schemas.datastream.net/MP_fields")
    protected String mobileicon;
    @XmlElement(name = "EXTMAINMENUTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    @XmlSchemaType(name = "string")
    protected EXTMAINMENUTYPE_Type extmainmenutype;
    @XmlElement(name = "UPDATECOUNT")
    protected Long updatecount;

    /**
     * Obtient la valeur de la propriété extmenuid.
     * 
     * @return
     *     possible object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public EXTMENUID_Type getEXTMENUID() {
        return extmenuid;
    }

    /**
     * Définit la valeur de la propriété extmenuid.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMENUID_Type }
     *     
     */
    public void setEXTMENUID(EXTMENUID_Type value) {
        this.extmenuid = value;
    }

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété functionid.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Définit la valeur de la propriété functionid.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Obtient la valeur de la propriété extmenuparent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Définit la valeur de la propriété extmenuparent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Obtient la valeur de la propriété extmenutype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Définit la valeur de la propriété extmenutype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Obtient la valeur de la propriété hidemenu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Définit la valeur de la propriété hidemenu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Obtient la valeur de la propriété mobile.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Définit la valeur de la propriété mobile.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Obtient la valeur de la propriété mobileicon.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Définit la valeur de la propriété mobileicon.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Obtient la valeur de la propriété extmainmenutype.
     * 
     * @return
     *     possible object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public EXTMAINMENUTYPE_Type getEXTMAINMENUTYPE() {
        return extmainmenutype;
    }

    /**
     * Définit la valeur de la propriété extmainmenutype.
     * 
     * @param value
     *     allowed object is
     *     {@link EXTMAINMENUTYPE_Type }
     *     
     */
    public void setEXTMAINMENUTYPE(EXTMAINMENUTYPE_Type value) {
        this.extmainmenutype = value;
    }

    /**
     * Obtient la valeur de la propriété updatecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Définit la valeur de la propriété updatecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUPDATECOUNT(Long value) {
        this.updatecount = value;
    }

}
